Exception: Spurline::AdapterNotFoundError

Inherits:
AgentError
  • Object
show all
Defined in:
lib/spurline/errors.rb

Overview

Raised when an adapter symbol cannot be resolved in the adapter registry. Ensure the adapter is registered before referencing it in use_model.