Exception: Spurline::InjectionAttemptError

Inherits:
AgentError
  • Object
show all
Defined in:
lib/spurline/errors.rb

Overview

Raised when the injection scanner detects a prompt injection pattern in content flowing through the context pipeline.